@@ -1,5 +1,5 @@
 /* Iterate over previous character in UTF-8 string.
-   Copyright (C) 2002, 2006-2007, 2009-2016 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2006-2007, 2009-2019 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2002.
 
    This program is free software: you can redistribute it and/or modify it
@@ -13,7 +13,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #include <config.h>
 
@@ -33,9 +33,7 @@ u8_prev (ucs4_t *puc, const uint8_t *s, const uint8_t *start)
           *puc = c_1;
           return s - 1;
         }
-#if CONFIG_UNICODE_SAFETY
       if ((c_1 ^ 0x80) < 0x40)
-#endif
         if (s - 1 != start)
           {
             uint8_t c_2 = s[-2];
@@ -46,38 +44,28 @@ u8_prev (ucs4_t *puc, const uint8_t *s, const uint8_t *start)
                        | (unsigned int) (c_1 ^ 0x80);
                 return s - 2;
               }
-#if CONFIG_UNICODE_SAFETY
             if ((c_2 ^ 0x80) < 0x40)
-#endif
               if (s - 2 != start)
                 {
                   uint8_t c_3 = s[-3];
 
                   if (c_3 >= 0xe0 && c_3 < 0xf0
-#if CONFIG_UNICODE_SAFETY
                       && (c_3 >= 0xe1 || c_2 >= 0xa0)
-                      && (c_3 != 0xed || c_2 < 0xa0)
-#endif
-                     )
+                      && (c_3 != 0xed || c_2 < 0xa0))
                     {
                       *puc = ((unsigned int) (c_3 & 0x0f) << 12)
                              | ((unsigned int) (c_2 ^ 0x80) << 6)
                              | (unsigned int) (c_1 ^ 0x80);
                       return s - 3;
                     }
-#if CONFIG_UNICODE_SAFETY
                   if ((c_3 ^ 0x80) < 0x40)
-#endif
                     if (s - 3 != start)
                       {
                         uint8_t c_4 = s[-4];
 
                         if (c_4 >= 0xf0 && c_4 < 0xf8
-#if CONFIG_UNICODE_SAFETY
                             && (c_4 >= 0xf1 || c_3 >= 0x90)
-                            && (c_4 < 0xf4 || (c_4 == 0xf4 && c_3 < 0x90))
-#endif
-                           )
+                            && (c_4 < 0xf4 || (c_4 == 0xf4 && c_3 < 0x90)))
                           {
                             *puc = ((unsigned int) (c_4 & 0x07) << 18)
                                    | ((unsigned int) (c_3 ^ 0x80) << 12)
